<?php

namespace Drupal\dynamic_library_loader\Service;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Cache\CacheTagsInvalidatorInterface;
use Psr\Log\LoggerInterface;

/**
 * Service that refreshes library files when the cache is cleared.
 */
class LibraryRefresher {

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The cache tags invalidator service.
   *
   * @var \Drupal\Core\Cache\CacheTagsInvalidatorInterface
   */
  protected $cacheInvalidator;

  /**
   * The logger service.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new LibraryRefresher instance.
   *
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param \Drupal\Core\Cache\CacheTagsInvalidatorInterface $cache_invalidator
   *   The cache invalidator service.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger service.
   */
  public function __construct(
    FileSystemInterface $file_system,
    ConfigFactoryInterface $config_factory,
    CacheTagsInvalidatorInterface $cache_invalidator,
    LoggerInterface $logger
  ) {
    $this->fileSystem = $file_system;
    $this->configFactory = $config_factory;
    $this->cacheInvalidator = $cache_invalidator;
    $this->logger = $logger;
  }

  /**
   * Refreshes library files when the cache is flushed.
   */
  public function refresh() {
    // Log the refresh action.
    $this->logger->notice('Refreshing library files after cache flush.');

    // Example logic: Clear library-related cache tags.
    $this->cacheInvalidator->invalidateTags(['library_info']);

    // Custom logic for refreshing files or aggregated assets.
    $this->refreshLibraryFiles();
  }

  /**
   * Custom method to handle library file refresh.
   */
  protected function refreshLibraryFiles() {
    $library_path = 'public://libraries/';
    if ($this->fileSystem->prepareDirectory($library_path, FileSystemInterface::CREATE_DIRECTORY)) {
      $this->logger->notice('Library directory prepared: @path', ['@path' => $library_path]);
    } else {
      $this->logger->error('Failed to prepare library directory: @path', ['@path' => $library_path]);
    }
  }
}